@@ -39,7 +39,6 @@ PluginDetail = namedtuple("PluginDetail",
      "showHomeLink",
      "showInTitleBar",
      "antIcon",
-     "titleSvgIcon",
      "titleBarText",
      "configLinkPath"])
 
@@ -137,7 +136,6 @@ class FrontendBuilderABC(BuilderABC):
             homeLinkText = jsonCfgNode.homeLinkText(plugin.title)
             showInTitleBar = jsonCfgNode.showInTitleBar(False)
             antIcon = jsonCfgNode.antIcon(None)
-            titleSvgIcon = jsonCfgNode.titleSvgIcon(None)
             titleBarText = jsonCfgNode.titleBarText(None)
             configLinkPath = jsonCfgNode.configLinkPath(None)
 
@@ -196,7 +194,6 @@ class FrontendBuilderABC(BuilderABC):
                     showHomeLink=showHomeLink,
                     showInTitleBar=showInTitleBar,
                     antIcon=antIcon,
-                    titleSvgIcon=titleSvgIcon,
                     titleBarText=titleBarText,
                     configLinkPath=configLinkPath)
             )
@@ -296,7 +293,6 @@ class FrontendBuilderABC(BuilderABC):
             links.append(dict(plugin=pluginDetail.pluginName,
                 text=pluginDetail.titleBarText,
                 antIcon=pluginDetail.antIcon,
-                svgIcon=pluginDetail.titleSvgIcon,
                 resourcePath="/%s" % pluginDetail.pluginName,
                 badgeCount=None))
 
@@ -359,7 +355,7 @@ class FrontendBuilderABC(BuilderABC):
 
         # initialise the arrays, and put in the persisted service module
         imports = [
-            '''import { PluginRootServicePersistentLoadModule } from "./plugin-root-services"''']
+            '''import { PluginRootServicePersistentLoadModule } from "@_peek/plugin-root-services"''']
         modules = ['PluginRootServicePersistentLoadModule']
 
         for pluginDetail in pluginDetails:
